# Copyright 2012-2014 Ravello Systems, Inc.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import, print_function

import six
import copy

from support import *
from ravello_sdk import *


class TestApplication(IntegrationTest):

    @property
    def created(self):
        return getattr(type(self), 'created', None)

    @property
    def keypair(self):
        return getattr(type(self), 'keypair', None)

    def test_aa_create_application(self):
        keypair = {'name': self.random_name(), 'publicKey': self.pubkey}
        keypair = self.client.create_keypair(keypair)
        self.assertIsInstance(keypair, dict)
        self.assertIsInstance(keypair['id'], six.integer_types)
        type(self).keypair = keypair
        imgid = self.config.getint('integration', 'image')
        image = self.client.get_image(imgid)
        self.assertIsInstance(image, dict)
        self.assertIsInstance(image['id'], six.integer_types)
        vm = copy.deepcopy(image)
        update_luids(vm)
        vm.update({'name': 'vm1', 'hostnames': ['vm1'],
                   'keypairId': self.keypair['id']})
        application = {'name': self.random_name(), 'publicKey': self.pubkey,
                       'design': {'vms': [vm]}}
        created = self.client.create_application(application)
        self.assertIsInstance(created, dict)
        self.assertIsInstance(created['id'], six.integer_types)
        self.assertIsInstance(created['name'], six.string_types)
        type(self).created = created

    def test_ab_publish_application(self):
        created = self.created
        if created is None:
            raise SkipTest('creation failed')
        self.client.publish_application(created)
        self.client.wait_for(created, lambda app: application_state(app) == 'STARTED', 600)
        type(self).created = self.client.get_application(created)

    def test_ac_stop_application(self):
        created = self.created
        if created is None or application_state(created) != 'STARTED':
            raise SkipTest('creation or start failed')
        self.client.stop_application(created)
        self.client.wait_for(created, lambda app: application_state(app) == 'STOPPED', 600)
        type(self).created = self.client.get_application(created)

    def test_ad_start_application(self):
        created = self.created
        if created is None or application_state(created) != 'STOPPED':
            raise SkipTest('creation or stop failed')
        self.client.start_application(created)
        self.client.wait_for(created, lambda app: application_state(app) == 'STARTED', 600)
        type(self).created = self.client.get_application(created)

    def test_ae_get_vnc_url(self):
        created = self.created
        if created is None or application_state(created) != 'STARTED':
            raise SkipTest('creation or start failed')
        vm = created['deployment']['vms'][0]
        url = self.client.get_vnc_url(created, vm)
        self.assertIsInstance(url, six.text_type)
        self.assertTrue(url.startswith('https://'))
        self.assertTrue('ravellosystems.com' in url)

    def test_zz_delete_application(self):
        created = self.created
        if created is None:
            raise SkipTest('creation failed')
        self.client.delete_application(created)
        app = self.client.get_application(created['id'])
        self.assertIsNone(app)
        self.client.delete_keypair(self.keypair)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
#
# Copyright 2012-2014 Ravello Systems, Inc.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import, print_function

from invoke import run, task


@task
def clean():
    run('find . -name __pycache__ | xargs rm -rf', echo=True)
    run('find . -name *.so | xargs rm -f', echo=True)
    run('rm -rf build dist', echo=True)


@task(clean)
def develop():
    run('python setup.py build', echo=True)
    if develop:
        run('python setup.py develop', echo=True)



# Copyright 2012-2014 Ravello Systems, Inc.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import, print_function

import six
import random
from support import *
from ravello_sdk import *


class TestReadAll(IntegrationTest):

    def test_get_applications(self):
        apps = self.client.get_applications()
        apps = random.sample(apps, min(10, len(apps)))
        self.assertIsInstance(apps, list)
        for app in apps:
            self.assertIsInstance(app, dict)
            self.assertIn('id', app)
            self.assertIn('name', app)
            self.assertIn('_href', app)
            app2 = self.client.reload(app)
            self.assertTrue(set(app).issubset(set(app2)))

    def test_get_blueprints(self):
        bps = self.client.get_blueprints()
        bps = random.sample(bps, min(10, len(bps)))
        self.assertIsInstance(bps, list)
        for bp in bps:
            self.assertIsInstance(bp, dict)
            self.assertIn('id', bp)
            self.assertIn('name', bp)
            self.assertIn('_href', bp)
            bp2 = self.client.reload(bp)
            self.assertTrue(set(bp).issubset(set(bp2)))

    def test_get_images(self):
        images = self.client.get_images()
        images = random.sample(images, min(10, len(images)))
        self.assertIsInstance(images, list)
        for img in images:
            self.assertIsInstance(img, dict)
            self.assertIn('id', img)
            self.assertIn('name', img)
            self.assertIn('_href', img)
            img2 = self.client.reload(img)
            # Idiosyncracy: the images list sometimes shows {} for CM, while
            # the individual image has an absent key.
            img.setdefault('configurationManagement', {})
            img2.setdefault('configurationManagement', {})
            self.assertTrue(set(img).issubset(set(img2)))

    def test_get_keypairs(self):
        kps = self.client.get_keypairs()
        kps = random.sample(kps, min(10, len(kps)))
        self.assertIsInstance(kps, list)
        for kp in kps:
            self.assertIsInstance(kp, dict)
            self.assertIn('id', kp)
            self.assertIn('name', kp)
            self.assertIn('_href', kp)
            kp2 = self.client.reload(kp)
            self.assertTrue(set(kp).issubset(set(kp2)))


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# A Ravello SDK example for creating and publishing applications from a blueprint
# 
# Copyright 2011-2016 Ravello Systems, Inc.
# 
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License.  You may obtain a copy
# of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
# License for the specific language governing permissions and limitations under
# the License.

import os
import sys
import base64
import getpass
import logging
import logging.handlers
from ravello_sdk import *

def get_credentials():
	with open(os.path.expanduser("~/.ravello_login"),"r") as pf:
		username = pf.readline().strip()
		encrypted_password = pf.readline().strip()
	password = base64.b64decode(encrypted_password).decode()
	return username,password

def get_user_credentials(username):
 
	password = None

	if username:
		password = getpass.getpass('Enter a Password: ')
	else:
		#read user credentials from .ravello_login file in user HOMEDIR
		username,password = get_credentials()

	if not username or not password:
		print('Error: User credentials are not set')
		return None,None

	return username,password

def initlog(log_file):
        logger = logging.getLogger()
        logger.setLevel(logging.INFO)
        logpath=os.path.join(os.getcwd(),log_file)
        handler = logging.handlers.RotatingFileHandler(logpath, maxBytes=1048576, backupCount=10)
        fmt = '%(asctime)s: %(filename)-20s %(levelname)-8s %(message)s'
        handler.setFormatter(logging.Formatter(fmt))
        logger.addHandler(handler)

def connect(username, password):
        client = RavelloClient()
        try:
                client.login(username, password)
        except Exception as e:
                sys.stderr.write('Error: {!s}\n'.format(e))
                print('Error: Invalid user credentials, username {0}'.format(username))
                return None
        return client

def get_app_id(app_name,client):
        app_id=0
        for app in client.get_applications():
                if app['name'].lower() == app_name.lower():
                        app_id = app['id']
                        break
        return app_id

